"""
Extensions for the Cacao framework.

This package contains various extensions that enhance Cacao's functionality.
"""

# Import extensions to make them available directly from cacao.extensions
from .react_extension import ReactExtension

__all__ = [
    "ReactExtension"
]